﻿-----------------------------------------------------------------------------

local Roster = AceLibrary("Roster-2.1")

-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AssessmentBigWigs")
L:RegisterTranslations("enUS", function() return {
	["Automatic BigWigs Record"] = true,
	["Automatic BigWigs record options."] = true,
	["Enable"] = true,
	["Save fight data automatically when BigWigs registers a boss kill."] = true,
	["Fight Name Tag"] = true,
	["Specify a tag that determines the save name of the fight data."] = true,
	["Any Tag String."] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Automatic BigWigs Record"] = "BigWigs 자동 기록",
	["Automatic BigWigs record options."] = "BigWigs 자동 기록 설정입니다.",
	["Enable"] = "사용",
	["Save fight data automatically when BigWigs registers a boss kill."] = "BigWigs에 등록된 보스를 죽였을 때 자동으로 전투 데이터를 기록합니다.",
	["Fight Name Tag"] = "전투명 태그",
	["Specify a tag that determines the save name of the fight data."] = "전투 데이터의 저장명을 지정하는 태그입니다.",
	["Any Tag String."] = "태그 문자열.",
} end)

-----------------------------------------------------------------------------

local AssessmentBigWigs = Assessment:NewModule("BigWigs", "AceEvent-2.0")
AssessmentBigWigs.db = Assessment:AcquireDBNamespace("BigWigs")
Assessment:RegisterDefaults("BigWigs", "profile", {
	enable = false,
	tag = "[Key], [FormatDate(\"%Y-%m-%d\")]",
})

-----------------------------------------------------------------------------

local profile

-----------------------------------------------------------------------------

Assessment.Options.args.data.args.automaticBigWigsRecord =
{
	type = "group",
	name = L["Automatic BigWigs Record"],
	desc = L["Automatic BigWigs record options."],
	args =
	{
		enable =
		{
			type = "toggle",
			name = L["Enable"],
			desc = L["Save fight data automatically when BigWigs registers a boss kill."],
			get = function() return profile.enable end,
			set = function(v) profile.enable = v AssessmentBigWigs:OnEnable() end,
		},
		tag =
		{
			type = "text",
			name = L["Fight Name Tag"],
			desc = L["Specify a tag that determines the save name of the fight data."],
			disabled = function() return not profile.enable end,
			get = function() return Assessment:HighlightTagSyntax(profile.tag, "string") end,
			set = function(v) profile.tag = Assessment:FixTagCasing(v, "string") end,
			usage = L["Any Tag String."],
		},
	},
	
}

-----------------------------------------------------------------------------

function AssessmentBigWigs:OnInitialize()
	profile = self.db.profile
end

function AssessmentBigWigs:OnEnable()
	if profile.enable then
		self:RegisterEvent("BigWigs_RecvSync")
	else
		self:CancelEvent("BigWigs_RecvSync")
	end
end

local function copyFightDataEvent(saveName)
	Assessment:CopyFightData(saveName, 1)
end

local tagData = { }
function AssessmentBigWigs:BigWigs_RecvSync(sync, module)
	if sync == "BossDeath" and type(module) == "string" then
		tagData.key = module
		tagData.fightData = Assessment:GetFightData(1)
		Assessment:ScheduleEvent(copyFightDataEvent, 0.1, Assessment:CompileTag(profile.tag, "string").method(tagData))
	end
end

-----------------------------------------------------------------------------
